@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class LabelsConfig(AppConfig):
-    name = 'apis_labels'
+    name = "apis_core.apis_labels"
